@@ -74,7 +74,9 @@ def train_model(config: Dict[str, Any]) -> None:
         logger=logger,
         log_every_n_steps=config["training"].get("log_every_n_steps", 10),
         deterministic=config["training"].get("deterministic", False),
-        gradient_clip_val=config["training"].get("gradient_clip_val", 0.0)
+        gradient_clip_val=config["training"].get("gradient_clip_val", 0.0),
+        check_val_every_n_epoch=config["training"].get("check_val_every_n_epoch", 1)
+        
     )
     
     # Train the model
